Implementation of the primitives used in Zcash and Iron Fish.
This is a fork of the original librustzcash project from
Zcash. The fork was created by the Iron Fish project to add performance
improvements.
Delta from upstream
These are the differences between this crate and the upstream
librustzcash:
Modules
- circuit
- Implementations of the Zcash circuits and Zcash-specific gadgets.
- constants
- Various constants used for the Zcash proofs.
- prover
local-proverorbundled-prover - Abstractions over the proving system and parameters for ease of use.
- sapling
- Helpers for creating Sapling proofs.
- sprout
- APIs for creating and verifying Sprout proofs.
Structs
Functions
- default_
params_ folder directories - Returns the default folder that the Zcash proving parameters are located in.
- download_
parameters download-params - Download the Zcash Sapling parameters, storing them in the default location.
- load_
parameters - parse_
parameters - Parse Bls12 keys from bytes as serialized by
Parameters::write.